@@ -5,7 +5,7 @@ import os
 
 def DebugLog(msg):
    if os.environ.has_key('DEBUG'):
-      print str(msg)
+      print msg
 
 def DebugFile(msg):
    if os.environ.has_key('DEBUG'):
