@@ -1,4 +1,4 @@
-﻿#!/usr/bin/python
+#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 import os, re
@@ -151,7 +151,7 @@ class QonsoExtractor(QtCore.QObject):
       request.setRawHeader("Keep-Alive", "115");
       request.setRawHeader("Referer", self.urlbeforeAuth)
       request.setRawHeader("Host", self.hostname)
-      request.setRawHeader("User-Agent", "Mozilla/5.0 (Windows NT 5.1; rv:2.0b10) Gecko/20100101 Firefox/4.0b10")
+      request.setRawHeader("User-Agent", "Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900")
       return request
 
    def PostRequest(self, params, request=None):
